@@ -2,11 +2,35 @@ package WWW::Connpass::Event::Waitlist;
 use strict;
 use warnings;
 
+sub _method { die 'this is abstruct method' }
+
 sub new {
-    my $class = shift;
-    bless {@_} => $class;
+    my ($class, %args) = @_;
+    die "$class is abstract class" if $class eq __PACKAGE__;
+
+    # assertion
+    if (exists $args{method}) {
+        $args{method} eq $class->_method
+            or die "Invalid method: $args{method}";
+    }
+    else {
+        $args{method} = $class->_method;
+    }
+
+    return bless \%args => $class;
 }
 
+sub inflate {
+    my ($class, %args) = @_;
+    $class .= '::'.ucfirst $args{method};
+    Module::Load::load($class);
+    return $class->new(%args);
+}
+
+sub raw_data { +{%{$_[0]}} }
+
+sub is_new { not exists shift->{id} }
+
 sub cancelled_count          { shift->{cancelled_count}           }
 sub id                       { shift->{id}                        }
 sub join_fee                 { shift->{join_fee}                  }
