@@ -4,16 +4,20 @@ use warnings;
 
 use Carp qw/croak/;
 use Web::Query qw/wq/;
+use Text::CSV_XS;
 use JSON 2;
 use URI;
 
 use WWW::Connpass::Agent;
 use WWW::Connpass::Event;
 use WWW::Connpass::Event::Questionnaire;
+use WWW::Connpass::Event::Participants;
 use WWW::Connpass::Group;
 use WWW::Connpass::Place;
 use WWW::Connpass::User;
 
+use constant DEBUG => $ENV{WWW_CONNPASS_DEBUG};
+
 my $_JSON = JSON->new->utf8;
 
 sub new {
@@ -44,7 +48,7 @@ sub _check_response_error_or_throw {
     my $res = shift;
     unless ($res->is_success) {
         my $message = sprintf '[ERROR] %d %s: %s', $res->code, $res->message, $res->decoded_content;
-        $message = "=REQUEST\n".$res->request->as_string."\nRESPONSE=\n".$res->as_string if $ENV{DEBUG};
+        $message = "=REQUEST\n".$res->request->as_string."\nRESPONSE=\n".$res->as_string if DEBUG;
         local $Carp::CarpLevel = $Carp::CarpLevel + 1;
         croak $message;
     }
@@ -154,7 +158,7 @@ sub register_place {
     _check_response_error_or_throw($res);
 
     my $data = $_JSON->decode($res->decoded_content);
-    return WWW::Connpass::Event::Place->new(session => $self, place => $data);
+    return WWW::Connpass::Place->new(session => $self, place => $data);
 }
 
 sub add_owner_to_event {
@@ -251,6 +255,47 @@ sub fetch_organized_groups {
     return map { WWW::Connpass::Group->new(session => $self, group => $_) } @$groups;
 }
 
+sub fetch_participants_info {
+    my ($self, $event) = @_;
+    my $uri = sprintf 'http://connpass.com/event/%d/participants_csv/', $event->id;
+
+    my $res = $self->{mech}->get($uri);
+    _check_response_error_or_throw($res);
+
+    # HTTP::Response
+    my $content = $res->decoded_content;
+
+    my $csv = Text::CSV_XS->new({ binary => 1, decode_utf8 => 0, eol => "\r\n", auto_diag => 1 });
+
+    my @questions = $event->questionnaire->questions;
+    my @params = qw/waitlist_name username nickname comment registration attendance/;
+    push @params => map { 'answer_'.$_ } keys @questions;
+    push @params => qw/updated_at receipt_id/;
+
+    my @lines = split /\r\n/, $content;
+    my %label; @label{@params} = do {
+        my $header = shift @lines;
+        my $success = $csv->parse($header);
+        die "Invalid CSV syntax: $header" unless $success;
+        $csv->fields;
+    };
+
+    my @rows;
+    for my $line (@lines) {
+        my $success = $csv->parse($line);
+        die "Invalid CSV syntax: $line" unless $success;
+
+        my %row;
+        @row{@params} = $csv->fields;
+        push @rows => \%row;
+    }
+
+    return WWW::Connpass::Event::Participants->new(
+        label => \%label,
+        rows  => \@rows,
+    );
+}
+
 1;
 __END__
 
